biz

package
v0.9.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Space

type Space struct {
	Trans    *util.Trans
	SpaceDAL *dal.Space
}

Space business logic layer

func (*Space) Create

func (a *Space) Create(ctx context.Context, formItem *schema.SpaceForm) (*schema.Space, error)

Create a new space in the data access object.

func (*Space) Delete

func (a *Space) Delete(ctx context.Context, id string) error

Delete the specified space from the data access object.

func (*Space) EnsureDefault

func (a *Space) EnsureDefault(ctx context.Context) error

EnsureDefault creates the built-in "default" space if it does not exist. Safe to call on every startup (idempotent).

func (*Space) Get

func (a *Space) Get(ctx context.Context, id string) (*schema.Space, error)

Get the specified space from the data access object.

func (*Space) Query

Query spaces from the data access object based on the provided parameters.

func (*Space) Update

func (a *Space) Update(ctx context.Context, id string, formItem *schema.SpaceForm) error

Update the specified space in the data access object.

Jump to